summary refs log tree commit diff
path: root/mousefunc.c
diff options
context:
space:
mode:
authorokan <okan>2011-05-05 19:52:52 +0000
committerokan <okan>2011-05-05 19:52:52 +0000
commit604a5d07a47ef516e83ac68d02861188d725951c (patch)
tree6cfb651317db4db35f4cae8db9aabd208129bf61 /mousefunc.c
parent8ed968601e207b31a21dbec19e61b17580d456b7 (diff)
downloadcwm-604a5d07a47ef516e83ac68d02861188d725951c.tar.gz
cwm-604a5d07a47ef516e83ac68d02861188d725951c.tar.xz
cwm-604a5d07a47ef516e83ac68d02861188d725951c.zip
bump window resize back to 60hz. instead, we should not need to sync
every time we move/resize a window, so remove XSync in both mouse move
and resize events.  tested by Brynet as well.

ok oga@
Diffstat (limited to 'mousefunc.c')
-rw-r--r--mousefunc.c8
1 files changed, 3 insertions, 5 deletions
diff --git a/mousefunc.c b/mousefunc.c
index 074f090..30eed53 100644
--- a/mousefunc.c
+++ b/mousefunc.c
@@ -106,10 +106,9 @@ mousefunc_window_resize(struct client_ctx *cc, void *arg)
 				/* Recompute window output */
 				mousefunc_sweep_draw(cc);
 
-			/* don't sync more than 10 times / second */
-			if ((ev.xmotion.time - time) > (1000 / 10)) {
+			/* don't resize more than 60 times / second */
+			if ((ev.xmotion.time - time) > (1000 / 60)) {
 				time = ev.xmotion.time;
-				XSync(X_Dpy, False);
 				client_resize(cc);
 			}
 			break;
@@ -159,10 +158,9 @@ mousefunc_window_move(struct client_ctx *cc, void *arg)
 			cc->geom.x = ev.xmotion.x_root - px - cc->bwidth;
 			cc->geom.y = ev.xmotion.y_root - py - cc->bwidth;
 
-			/* don't sync more than 60 times / second */
+			/* don't move more than 60 times / second */
 			if ((ev.xmotion.time - time) > (1000 / 60)) {
 				time = ev.xmotion.time;
-				XSync(X_Dpy, False);
 				client_move(cc);
 			}
 			break;